import { declare } from '@babel/helper-plugin-utils';
import { types } from '@babel/core';

var index = declare((api, options) => {
  api.assertVersion("8.0.0-alpha.6");
  const {
    helperVersion = "7.0.0-beta.0",
    whitelist = false
  } = options;
  if (whitelist !== false && (!Array.isArray(whitelist) || whitelist.some(w => typeof w !== "string"))) {
    throw new Error(".whitelist must be undefined, false, or an array of strings");
  }
  const helperWhitelist = whitelist ? new Set(whitelist) : null;
  return {
    name: "external-helpers",
    pre(file) {
      file.set("helperGenerator", name => {
        if (file.availableHelper && !file.availableHelper(name, helperVersion)) {
          return;
        }
        if (helperWhitelist && !helperWhitelist.has(name)) return;
        return types.memberExpression(types.identifier("babelHelpers"), types.identifier(name));
      });
    }
  };
});

export { index as default };
//# sourceMappingURL=index.js.map
